@@ -6,32 +6,60 @@
  * @ref License
  */
 
-/* LICENSE
- *
- * Copyright (c) 2008-2019 OpenShot Studios, LLC
- * <http://www.openshotstudios.com/>. This file is part of
- * OpenShot Library (libopenshot), an open-source project dedicated to
- * delivering high quality video editing and animation solutions to the
- * world. For more information visit <http://www.openshot.org/>.
- *
- * OpenShot Library (libopenshot) is free software: you can redistribute it
- * and/or modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * OpenShot Library (libopenshot) is distributed in the hope that it will be
- * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with OpenShot Library. If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (c) 2008-2019 OpenShot Studios, LLC
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
-#include "../include/ClipBase.h"
+#include "ClipBase.h"
+#include "Timeline.h"
 
 using namespace openshot;
 
+// Set position on timeline (in seconds)
+void ClipBase::Position(float value) {
+
+	position = value;
+
+	if (ParentTimeline()) {
+		// Resort timeline items (internal clips/effects arrays)
+		Timeline *parentTimeline = (Timeline *) ParentTimeline();
+		parentTimeline->SortTimeline();
+	}
+}
+
+// Set layer of clip on timeline (lower number is covered by higher numbers)
+void ClipBase::Layer(int value) {
+	layer = value;
+
+	if (ParentTimeline()) {
+		// Resort timeline items (internal clips/effects arrays)
+		Timeline *parentTimeline = (Timeline *) ParentTimeline();
+		parentTimeline->SortTimeline();
+	}
+}
+
+// Set start position (in seconds) of clip (trim start of video)
+void ClipBase::Start(float value) {
+	start = value;
+
+	if (ParentTimeline()) {
+		// Resort timeline items (internal clips/effects arrays)
+		Timeline *parentTimeline = (Timeline *) ParentTimeline();
+		parentTimeline->SortTimeline();
+	}
+}
+
+// Set end position (in seconds) of clip (trim end of video)
+void ClipBase::End(float value) {
+	end = value;
+
+	if (ParentTimeline()) {
+		// Resort timeline items (internal clips/effects arrays)
+		Timeline *parentTimeline = (Timeline *) ParentTimeline();
+		parentTimeline->SortTimeline();
+	}
+}
+
 // Generate Json::Value for this object
 Json::Value ClipBase::JsonValue() const {
 
