@@ -6,33 +6,16 @@
  * @ref License
  */
 
-/* LICENSE
- *
- * Copyright (c) 2008-2019 OpenShot Studios, LLC
- * <http://www.openshotstudios.com/>. This file is part of
- * OpenShot Library (libopenshot), an open-source project dedicated to
- * delivering high quality video editing and animation solutions to the
- * world. For more information visit <http://www.openshot.org/>.
- *
- * OpenShot Library (libopenshot) is free software: you can redistribute it
- * and/or modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * OpenShot Library (libopenshot) is distributed in the hope that it will be
- * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with OpenShot Library. If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (c) 2008-2019 OpenShot Studios, LLC
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "EffectInfo.h"
+#include "Effects.h"
+#include "effects/AnalogTape.h"
 
 using namespace openshot;
 
-
 // Generate JSON string of this object
 std::string EffectInfo::Json() {
 
@@ -43,6 +26,9 @@ std::string EffectInfo::Json() {
 // Create a new effect instance
 EffectBase* EffectInfo::CreateEffect(std::string effect_type) {
 	// Init the matching effect object
+	if (effect_type == "AnalogTape")
+		return new AnalogTape();
+
 	if (effect_type == "Bars")
 		return new Bars();
 
@@ -58,6 +44,9 @@ EffectBase* EffectInfo::CreateEffect(std::string effect_type) {
 	else if (effect_type == "ChromaKey")
 		return new ChromaKey();
 
+	else if (effect_type == "ColorMap")
+		return new ColorMap();
+
 	else if (effect_type == "ColorShift")
 		return new ColorShift();
 
@@ -70,6 +59,9 @@ EffectBase* EffectInfo::CreateEffect(std::string effect_type) {
 	else if (effect_type == "Hue")
 		return new Hue();
 
+	else if (effect_type == "LensFlare")
+		return new LensFlare();
+
 	else if (effect_type == "Mask")
 		return new Mask();
 
@@ -82,9 +74,15 @@ EffectBase* EffectInfo::CreateEffect(std::string effect_type) {
 	else if (effect_type == "Saturation")
 		return new Saturation();
 
+	else if (effect_type == "Sharpen")
+		return new Sharpen();
+
 	else if (effect_type == "Shift")
 		return new Shift();
 
+	else if (effect_type == "SphericalProjection")
+		return new SphericalProjection();
+
 	else if (effect_type == "Wave")
 		return new Wave();
 
@@ -116,13 +114,16 @@ EffectBase* EffectInfo::CreateEffect(std::string effect_type) {
 		return new Whisperization();
 
 	#ifdef USE_OPENCV
+	else if (effect_type == "Outline")
+		return new Outline();
+	
 	else if(effect_type == "Stabilizer")
 		return new Stabilizer();
 
 	else if(effect_type == "Tracker")
 		return new Tracker();
-		
-	else if(effect_type == "Object Detector")
+
+	else if(effect_type == "ObjectDetection")
 		return new ObjectDetection();
 	#endif
 
@@ -136,20 +137,25 @@ Json::Value EffectInfo::JsonValue() {
 	Json::Value root;
 
 	// Append info JSON from each supported effect
+	root.append(AnalogTape().JsonInfo());
 	root.append(Bars().JsonInfo());
 	root.append(Blur().JsonInfo());
 	root.append(Brightness().JsonInfo());
 	root.append(Caption().JsonInfo());
 	root.append(ChromaKey().JsonInfo());
+	root.append(ColorMap().JsonInfo());
 	root.append(ColorShift().JsonInfo());
 	root.append(Crop().JsonInfo());
 	root.append(Deinterlace().JsonInfo());
 	root.append(Hue().JsonInfo());
+	root.append(LensFlare().JsonInfo());
 	root.append(Mask().JsonInfo());
 	root.append(Negate().JsonInfo());
 	root.append(Pixelate().JsonInfo());
 	root.append(Saturation().JsonInfo());
+	root.append(Sharpen().JsonInfo());
 	root.append(Shift().JsonInfo());
+	root.append(SphericalProjection().JsonInfo());
 	root.append(Wave().JsonInfo());
 	/* Audio */
 	root.append(Noise().JsonInfo());
@@ -163,7 +169,8 @@ Json::Value EffectInfo::JsonValue() {
 	root.append(Whisperization().JsonInfo());
 
 	#ifdef USE_OPENCV
-	root.append(Stabilizer().JsonInfo());
+	root.append(Outline().JsonInfo());
+	root.append(Stabilizer().JsonInfo());	
 	root.append(Tracker().JsonInfo());
 	root.append(ObjectDetection().JsonInfo());
 	#endif
