@@ -26,8 +26,8 @@ namespace openshot {
 
 	/// This enumeration designates the type of stream when encoding (video or audio)
 	enum StreamType {
-		VIDEO_STREAM,    ///< A video stream (used to determine which type of stream)
-		AUDIO_STREAM     ///< An audio stream (used to determine which type of stream)
+		VIDEO_STREAM,	///< A video stream (used to determine which type of stream)
+		AUDIO_STREAM	///< An audio stream (used to determine which type of stream)
 	};
 
 	/**
@@ -116,7 +116,6 @@ namespace openshot {
 	class FFmpegWriter : public WriterBase {
 	private:
 		std::string path;
-		int cache_size;
 		bool is_writing;
 		bool is_open;
 		int64_t video_timestamp;
@@ -135,9 +134,10 @@ namespace openshot {
 		uint8_t *audio_outbuf;
 		uint8_t *audio_encoder_buffer;
 
-		int num_of_rescalers;
-		int rescaler_position;
-		std::vector<SwsContext *> image_rescalers;
+		AVFrame *persistent_src_frame = nullptr;
+		AVFrame *persistent_dst_frame = nullptr;
+		uint8_t *persistent_dst_buffer = nullptr;
+		int persistent_dst_size = 0;
 
 		int audio_outbuf_size;
 		int audio_input_frame_size;
@@ -152,15 +152,6 @@ namespace openshot {
 		int original_channels;
 
 		std::shared_ptr<openshot::Frame> last_frame;
-		std::deque<std::shared_ptr<openshot::Frame> > spooled_audio_frames;
-		std::deque<std::shared_ptr<openshot::Frame> > spooled_video_frames;
-
-		std::deque<std::shared_ptr<openshot::Frame> > queued_audio_frames;
-		std::deque<std::shared_ptr<openshot::Frame> > queued_video_frames;
-
-		std::deque<std::shared_ptr<openshot::Frame> > processed_frames;
-		std::deque<std::shared_ptr<openshot::Frame> > deallocate_frames;
-
 		std::map<std::shared_ptr<openshot::Frame>, AVFrame *> av_frames;
 
 		/// Add an AVFrame to the cache
@@ -190,11 +181,6 @@ namespace openshot {
 		/// initialize streams
 		void initialize_streams();
 
-		/// @brief Init a collection of software rescalers (thread safe)
-		/// @param source_width The source width of the image scalers (used to cache a bunch of scalers)
-		/// @param source_height The source height of the image scalers (used to cache a bunch of scalers)
-		void InitScalers(int source_width, int source_height);
-
 		/// open audio codec
 		void open_audio(AVFormatContext *oc, AVStream *st);
 
@@ -205,13 +191,13 @@ namespace openshot {
 		void process_video_packet(std::shared_ptr<openshot::Frame> frame);
 
 		/// write all queued frames' audio to the video file
-		void write_audio_packets(bool is_final);
+		void write_audio_packets(bool is_final, std::shared_ptr<openshot::Frame> frame);
 
 		/// write video frame
 		bool write_video_packet(std::shared_ptr<openshot::Frame> frame, AVFrame *frame_final);
 
 		/// write all queued frames
-		void write_queued_frames();
+		void write_frame(std::shared_ptr<Frame> frame);
 
 	public:
 
@@ -224,9 +210,6 @@ namespace openshot {
 		/// Close the writer
 		void Close();
 
-		/// Get the cache size (number of frames to queue before writing)
-		int GetCacheSize() { return cache_size; };
-
 		/// Determine if writer is open or closed
 		bool IsOpen() { return is_open; };
 
@@ -243,9 +226,6 @@ namespace openshot {
 		/// by the Open() method if this method has not yet been called.
 		void PrepareStreams();
 
-		/// Remove & deallocate all software scalers
-		void RemoveScalers();
-
 		/// @brief Set audio resample options
 		/// @param sample_rate The number of samples per second of the audio
 		/// @param channels The number of audio channels
@@ -273,10 +253,6 @@ namespace openshot {
 		/// \note This is an overloaded function.
 		void SetAudioOptions(std::string codec, int sample_rate, int bit_rate);
 
-		/// @brief Set the cache size
-		/// @param new_size The number of frames to queue before writing to the file
-		void SetCacheSize(int new_size) { cache_size = new_size; };
-
 		/// @brief Set video export options
 		/// @param has_video Does this file need a video stream
 		/// @param codec The codec used to encode the images in this video
@@ -335,8 +311,15 @@ namespace openshot {
 		/// by the Close() method if this method has not yet been called.
 		void WriteTrailer();
 
+		/// @brief Add spherical (360°) video metadata to the video stream
+		/// @param projection The projection type (e.g., "equirectangular", "cubemap")
+		/// @param yaw_deg The yaw angle in degrees (horizontal orientation, default 0)
+		/// @param pitch_deg The pitch angle in degrees (vertical orientation, default 0)
+		/// @param roll_deg The roll angle in degrees (tilt orientation, default 0)
+		void AddSphericalMetadata(const std::string& projection="equirectangular", float yaw_deg=0.0f, float pitch_deg=0.0f, float roll_deg=0.0f);
+
 	};
 
-}
+} // namespace openshot
 
 #endif
