@@ -12,6 +12,7 @@
 
 #include "Deinterlace.h"
 #include "Exceptions.h"
+#include <omp.h>
 
 using namespace openshot;
 
@@ -51,21 +52,35 @@ std::shared_ptr<openshot::Frame> Deinterlace::GetFrame(std::shared_ptr<openshot:
 	int original_width = frame->GetImage()->width();
 	int original_height = frame->GetImage()->height();
 
-	// Get the frame's image
-	std::shared_ptr<QImage> image = frame->GetImage();
+	// Access the current QImage and its raw pixel data
+	auto image           = frame->GetImage();
 	const unsigned char* pixels = image->bits();
+	int line_bytes       = image->bytesPerLine();
 
-	// Create a smaller, new image
-	QImage deinterlaced_image(image->width(), image->height() / 2, QImage::Format_RGBA8888_Premultiplied);
-	const unsigned char* deinterlaced_pixels = deinterlaced_image.bits();
+	// Decide whether to copy even lines (start = 0) or odd lines (start = 1)
+	int start = isOdd ? 1 : 0;
 
-	// Loop through the scanlines of the image (even or odd)
-	int start = 0;
-	if (isOdd)
-		start = 1;
-	for (int row = start; row < image->height(); row += 2) {
-		memcpy((unsigned char*)deinterlaced_pixels, pixels + (row * image->bytesPerLine()), image->bytesPerLine());
-		deinterlaced_pixels += image->bytesPerLine();
+	// Compute how many rows we will end up copying
+	// If start = 0, rows_to_copy = ceil(original_height / 2.0)
+	// If start = 1, rows_to_copy = floor(original_height / 2.0)
+	int rows_to_copy = (original_height - start + 1) / 2;
+
+	// Create a new image with exactly 'rows_to_copy' scanlines
+	QImage deinterlaced_image(
+		original_width,
+		rows_to_copy,
+		QImage::Format_RGBA8888_Premultiplied
+	);
+	unsigned char* deinterlaced_pixels = deinterlaced_image.bits();
+
+	// Copy every other row from the source into the new image
+	// Parallelize over 'i' so each thread writes to a distinct slice of memory
+#pragma omp parallel for
+	for (int i = 0; i < rows_to_copy; i++) {
+		int row = start + 2 * i;
+		const unsigned char* src = pixels + (row * line_bytes);
+		unsigned char* dst       = deinterlaced_pixels + (i * line_bytes);
+		memcpy(dst, src, line_bytes);
 	}
 
 	// Resize deinterlaced image back to original size, and update frame's image
@@ -134,7 +149,7 @@ std::string Deinterlace::PropertiesJSON(int64_t requested_frame) const {
 	Json::Value root = BasePropertiesJSON(requested_frame);
 
 	// Add Is Odd Frame choices (dropdown style)
-	root["isOdd"] = add_property_json("Is Odd Frame", isOdd, "bool", "", NULL, 0, 1, true, requested_frame);
+	root["isOdd"] = add_property_json("Is Odd Frame", isOdd, "bool", "", NULL, 0, 1, false, requested_frame);
 	root["isOdd"]["choices"].append(add_property_choice_json("Yes", true, isOdd));
 	root["isOdd"]["choices"].append(add_property_choice_json("No", false, isOdd));
 
